/*==============================================================================
   REPORT_C.C :- Report Executor Demo Program (MS Windows Version)
   Sub Systems, Inc.
   Software License Agreement  (2006)
   ----------------------------------
   This is a demo program.  The program shows how you can utilize the Report
   Ease routines to perform develop report templates and execute the reports.
===============================================================================*/

#include "windows.h"
#include "stdio.h"
#include "stdlib.h"
#include "fcntl.h"
#include "sys\types.h"
#include "sys\stat.h"
#include "io.h"
#include "dos.h"
#include "string.h"
#include "math.h"

#if defined(__TURBOC__)
   #include "dir.h"
   #include "mem.h"
#else
   #include "memory.h"
#endif


/******************************************************************************
    WIN32 specific defines
*******************************************************************************/
#if defined (_WIN32)
   #if !defined(WIN32)
     #define WIN32
   #endif
#endif
#if defined (WIN32)
   #undef  huge
   #define huge
   #undef  FreeProcInstance
   #define FreeProcInstance(x)
   #define COMMAND_ID(wp,lp)        LOWORD(wp)
   #define CONTROL_ID(wp,lp)        LOWORD(wp)
   #define NOTIFY_MSG(wp,lp)        HIWORD(wp)
   #undef  farmalloc
   #define farmalloc  malloc
   #undef  farrealloc
   #define farrealloc realloc
   #undef  farfree
   #define farfree    free
#else
   #define COMMAND_ID(wp,lp)        (wp)
   #define CONTROL_ID(wp,lp)        (wp)
   #define NOTIFY_MSG(wp,lp)        HIWORD(lp)
#endif

BOOL InitInstance(HANDLE,int);
int     OurPrintf(LPSTR,...);
HWND hDemoWin=NULL;

/******************************************************************************
    DLL and demo program specific includes
*******************************************************************************/
#include "rep.h"

/****************************************************************************
        Main Fuction
******************************************************************************/
int PASCAL WinMain(HINSTANCE hInstance,HINSTANCE hPrevInstance,LPSTR lpCmdLine,int nCmdShow)
{
    MSG msg;

    if (!InitInstance(hInstance, nCmdShow))
        return (FALSE);

    while (IsWindow(hDemoWin) && GetMessage(&msg, NULL, 0, 0)) {
        TranslateMessage(&msg);
        DispatchMessage(&msg); 
    }             

    return (msg.wParam);
}

/****************************************************************************
    Save instance handle and create main window
****************************************************************************/

BOOL InitInstance(HANDLE hInstance,int nCmdShow)
{
    struct StrRep RepParm;

    hDemoWin = CreateWindow(
        REP_CLASS,
        "Report Executor Demo",
        WS_OVERLAPPEDWINDOW|REP_VSCROLL|REP_HSCROLL|REP_MENU|REP_TOOLBAR,
        CW_USEDEFAULT,
        CW_USEDEFAULT,
        CW_USEDEFAULT,
        CW_USEDEFAULT,
        NULL,
        NULL,
        hInstance,
        NULL
    );

    if (!hDemoWin)
        return (FALSE);

    ShowWindow(hDemoWin, nCmdShow);
    UpdateWindow(hDemoWin);

    memset(&RepParm,0,sizeof(RepParm));

    //****** initialize the structure variables *********
    RepParm.device='S';            // screen output

    RepParm.x=0;                  // Initial X position of FORM edit window
    RepParm.y=0;                  // Initial Y position of FORM edit window
    RepParm.width=GetSystemMetrics(SM_CXSCREEN);        // Initial edit window width
    RepParm.height=(GetSystemMetrics(SM_CYSCREEN)*9)/10; // Initial edit window height
    RepParm.ShowMenu=TRUE;        // display menu
    RepParm.ShowToolbar=TRUE;     // display the toolbar
    strcpy(RepParm.file,"");      // Text file name if the input type is 'F'
    RepParm.hInst=hInstance;          // Current application instant handle
    RepParm.style=WS_OVERLAPPEDWINDOW; //  Editor window style
    strcpy(RepParm.DataSetName,"CUSTOMER");

    strcpy(RepParm.SwapDir,"");         // screen page swap location
    RepParm.SuppressPrintMessages=FALSE;// display print time messages
    RepParm.UseCurrentPrinter=FALSE;    // Let the 'report-parameter' control current printer selection
    RepParm.OutFile[0]=0;               // output file
    RepParm.TextPitch=0;                // default text pitch

    strcpy(RepParm.DataSetName,"CUSTOMER");
    strcpy(RepParm.MasterDefFile,"customer.df");       // contains customer record definition
    strcpy(RepParm.DetailDefFile,"sales.df");         // contains sales order record defintion
    strcpy(RepParm.OtherDefFiles,"states.df,custtype.df");   // contains state name and customer type record defintion

    strcpy(RepParm.MasterDataFile,"customer.db");       // contains customer records
    strcpy(RepParm.DetailDataFile,"sales.db");         // contains sales order records
    strcpy(RepParm.OtherDataFiles,"states.db,custtype.db");    // contains state name and customer records
    
    strcpy(RepParm.PictureNameFile,"PictNames.txt");   // contains picture ids and picture file names

    RepParm.AutoRun=TRUE;             // run the report automatically using the datafile and template specified in this structure

    RepInit2(hDemoWin,&RepParm);

    return (TRUE);
}

/******************************************************************************
    OurPrintf:
    This routine formats and display a given set of arguments.  The format
    is given by the first argument.  The argument 2 to n contain the
    arguments for the specified format.  The function uses MessageBox to
    display the formatted string.
******************************************************************************/
int OurPrintf(LPSTR fmt,...)
{
    LPSTR ArgStart;
    char string[300];
    HWND hWnd;

    ArgStart=(LPSTR) &fmt;  // pointer to first argument
    ArgStart=&ArgStart[4];  // go past the first argument
    wvsprintf(string,fmt,ArgStart);

    if (NULL!=(hWnd=FindWindow("DBWin",NULL))) { // debug window open
        if (NULL!=(hWnd=GetWindow(hWnd,GW_CHILD))) {    // get the edit window
           int len=lstrlen(string);
           string[len]=0xd;
           string[len+1]=0xa;
           string[len+2]=0;
           #if defined (WIN32)
              SendMessage(hWnd,EM_SETSEL,32767,32767);  // show the last line
              SendMessage(hWnd,EM_REPLACESEL,0,(DWORD)(LPSTR)string);
              SendMessage(hWnd,EM_SCROLLCARET,0,0);     // scroll caret into view
           #else
              SendMessage(hWnd,EM_SETSEL,0,MAKELPARAM(32767,32767));  // show the last line
              SendMessage(hWnd,EM_REPLACESEL,0,(DWORD)(LPSTR)string);
              SendMessage(hWnd,EM_SETSEL,0,MAKELPARAM(32767,32767));  // show the last line
           #endif
        }
    }
    else MessageBox(NULL,string,NULL,MB_OK);
    return TRUE;
}

